Stan Math Library: stan/math/rev/mat/fun/cholesky_decompose.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions
cholesky_decompose.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/prim/mat/fun/cholesky_decompose.hpp>`
`#include <stan/math/rev/scal/fun/value_of_rec.hpp>`
`#include <stan/math/rev/scal/fun/value_of.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/prim/mat/fun/value_of_rec.hpp>`
`#include <stan/math/prim/mat/err/check_pos_definite.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/prim/mat/err/check_symmetric.hpp>`

Go to the source code of this file.

## Classes
class | stan::math::cholesky_decompose_v_vari

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
Eigen::Matrix< var,-1,-1 > | stan::math::cholesky_decompose (const Eigen::Matrix< var,-1,-1 > &A)

[ Stan Home Page ] © 2011–2016, Stan Development Team.